<!-- !split -->
<!-- jupyter-book 09_03_testdoc.md -->
# Appendix: Testing identical titles

<div id="test:title:id2"></div>

What about inserting a quiz?



## Test of quizzes


**Fundamental test:** What is the capital of Norway?

**Answer 1:**
 Stockholm

**Answer 2:**
 London

**Answer 3:**
 Oslo

**Choice D:**
 Bergen



